# MVNeuro

[![CircleCI](https://circleci.com/gh/hugorichard/mvneuro.svg?style=svg)](https://circleci.com/gh/hugorichard/mvneuro)

# Install 

`pip install mvneuro`

This code provides sklearn-like API for multiview problems.
